#
# Cookbook Name:: gitlab_omnibus
# Recipe:: default
#
# Copyright (c) 2015 Drew Blessing, All Rights Reserved.

# Set package URL based on version unless user set URL explicitly
if node['gitlab_omnibus']['package_url'].include?('<version>')
  node.default['gitlab_omnibus']['package_url'].gsub!(
    '<version>', node['gitlab_omnibus']['version']
  )
end
node.default['gitlab_omnibus']['package_name'] =
  node['gitlab_omnibus']['package_url'].split('/').last
package_path =
  "#{Chef::Config[:file_cache_path]}/#{node['gitlab_omnibus']['package_name']}"

unless node['gitlab_omnibus']['install_package_from_repo'] # ~FC023
  remote_file package_path do
    source node['gitlab_omnibus']['package_url']
    mode '0644'
  end
end

execute '/usr/bin/gitlab-ctl reconfigure' do
  action :nothing
  subscribes :run, 'template[/etc/gitlab/gitlab.rb]', :immediately
end

package 'gitlab' do
  source package_path unless node['gitlab_omnibus']['install_package_from_repo']
  action :install
  if node['platform'] == 'centos'
    provider Chef::Provider::Package::Rpm
  elsif node['platform'] =~ /debian|ubuntu/
    provider Chef::Provider::Package::Dpkg
  end
  # reconfigure on upgrade (won't have effect on 1st install)
  notifies :run, 'execute[/usr/bin/gitlab-ctl reconfigure]', :delayed
end

template '/etc/gitlab/gitlab.rb' do
  source 'gitlab.rb.erb'
  mode '0640'
end

service 'gitlab' do
  start_command '/usr/bin/gitlab-ctl start'
  stop_command '/usr/bin/gitlab-ctl stop'
  status_command '/usr/bin/gitlab-ctl status'
  restart_command '/usr/bin/gitlab-ctl restart'
  action :start
  supports restart: true, status: true
  provider Chef::Provider::Service::Simple
end

if node['gitlab_omnibus']['backup']['enable']
  include_recipe 'gitlab_omnibus::_backup'
end
